# frozen_string_literal: true

#
# @summary : determine the benchmark to be used for the manifest
#
# This function determins the  product_version to use for this call. It uses the following algorithmn:
#
# 1. Use the specified version for this system
# 2. Use a generic specified version for all systems
# 3. Check if fact db2_version is set. If not, return an undef
# 4. Use the version based on the version of the system
#
# @param [String[1]] system The system system
#
# See the file "LICENSE" for the full license governing this code.
#
Puppet::Functions.create_function('linux_secured::default_product_version') do
  dispatch :default_product_version do
    param 'String[1]', :identifier
  end

  def default_product_version(identifier)
    #
    # When a version is specified, use it.
    #
    value = lookup_setting('product_version', nil)
    return value if value
    #
    # When the version fact is available, use it
    #
    name = closure_scope['os']['name']
    product_version = closure_scope['os']['release']['major']
    value = supported_os.dig(name, product_version)
    fail "system version #{product_version} not recognised" if value.nil? 
    value
  end

  def supported_os
    @supported_os||= call_function('lookup', "linux_secured::supported_os", data_type('Hash'), 'first', nil)
  end

  def lookup_setting(system, default_value)
    call_function('linux_secured::lookup_setting', system, default_value)
  end

  def data_type(string)
    parser = Puppet::Pops::Types::TypeParser.singleton
    parser.parse(string)
  end
end
