#
# linux_secured::controls::bootloader_password_is_set
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlSetting the boot loader password will require that anyone rebootingthe system must enter a password before being able to set command line boot parameters.## RationaleRequiring a boot password upon execution of the boot loader will prevent an unauthorized user from entering boot parameters or changing the boot partition. This prevents users from weakening security (e.g. turning off SELinux at boot time).## ImpactIf password protection is enabled, only the designated superuser can edit a Grub 2 menu item by pressing "e" or access the GRUB 2 command line by pressing "c"You can add --unrestricted to the menu entries to allow the system to boot without entering a password. Password will still be required to edit menu items.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::bootloader_password_is_set: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `bootloader_password_is_set` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 1.4.1- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 1.4.1
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::bootloader_password_is_set (
  Optional[Sensitive] $password  = linux_secured::lookup_setting('password', undef),
) {
  # lint:ignore:strict_indent
  $script = @(SCRIPT)
  #!/usr/bin/env bash

  {
    tst1="" tst2="" output=""
    grubdir=$(dirname "$(find /boot -type f \( -name 'grubenv' -o -name 'grub.conf' -o -name 'grub.cfg' \) -exec grep -El '^\s*(kernelopts=|linux|kernel)' {} \;)")
    if [ -f "$grubdir/user.cfg" ]; then
        grep -Pq '^\h*GRUB2_PASSWORD\h*=\h*.+$' "$grubdir/user.cfg" && output="bootloader password set in \"$grubdir/user.cfg\""
    fi
    if [ -z "$output" ]; then
        grep -Piq '^\h*set\h+superusers\h*=\h*"?[^"\n\r]+"?(\h+.*)?$' "$grubdir/grub.cfg" && tst1=pass
        grep -Piq '^\h*password(_pbkdf2)?\h+\H+\h+.+$' "$grubdir/grub.cfg" && tst2=pass
        [ "$tst1" = pass ] && [ "$tst2" = pass ] && output="bootloader password set in \"$grubdir/grub.cfg\""
    fi
    [ -n "$output" ] && echo -e "PASSED! $output"
  } | grep PASSED!
  | SCRIPT
  # lint:endignore:strict_indent

  linux_secured_setup { "bootloader_password_is_set on ${title}":
    ensure => 'present',
  }
  if $password == undef {
    easy_type::delegate_to_validator()
  } else {
    exec { "Set grub password on ${title}":
      command => "echo \"${password.unwrap}\n${password.unwrap}\n\" > grub2-setpassword",
      path    => ['/usr/sbin/', '/usr/bin'],
      unless  => "bash ${script}",
    }

    ~> exec { "Update grub config on ${title}":
      command     => "grub2-mkconfig -o \"$(dirname \"$(find /boot -type f \\( -name 'grubenv' -o - name 'grub.conf' -o -name 'grub.cfg' \\) -exec grep -Pl '^\\h*(kernelopts=|linux|kernel)' {} \\;)\")/grub.cfg\"",
      path        => ['/usr/sbin/', '/usr/bin'],
      refreshonly => true,
    }
  }
}
