#
# linux_secured::controls::ssh_access_is_limited
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThere are several options available to limit which users and group can access the system via SSH. It is recommended that at least one of the following options be leveraged:- AllowUsers:o The AllowUsers variable gives the system administrator the option ofallowing specific users to ssh into the system. The list consists of space separated user names. Numeric user IDs are not recognized with this variable. If a system administrator wants to restrict user access further by only allowing the allowed users to log in from a particular host, the entry can be specified in the form of user@host.- AllowGroups:o The AllowGroups variable gives the system administrator the option ofallowing specific groups of users to ssh into the system. The list consists of space separated group names. Numeric group IDs are not recognized with this variable.- DenyUsers:o The DenyUsers variable gives the system administrator the option of denyingspecific users to ssh into the system. The list consists of space separated user names. Numeric user IDs are not recognized with this variable. If a system administrator wants to restrict user access further by specifically denying a user's access from a particular host, the entry can be specified in the form of user@host.- DenyGroups:o The DenyGroups variable gives the system administrator the option ofdenying specific groups of users to ssh into the system. The list consists of space separated group names. Numeric group IDs are not recognized with this variable.## RationaleRestricting which users can remotely access the system via SSH will help ensure that only authorized users access the system.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::ssh_access_is_limited: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `ssh_access_is_limited` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.2.4- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.2.4
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::ssh_access_is_limited (
  Optional[Array[String[1]]]  $allow_users  = linux_secured::lookup_setting('allow_users', undef),
  Optional[Array[String[1]]]  $allow_groups = linux_secured::lookup_setting('allow_groups', undef),
  Optional[Array[String[1]]]  $deny_users   = linux_secured::lookup_setting('deny_users', undef),
  Optional[Array[String[1]]]  $deny_groups  = linux_secured::lookup_setting('deny_groups', undef),
) {
  linux_secured_setup { "ssh_access_is_limited on ${title}":
    ensure => 'present',
  }

  if $allow_users != undef {
    ini_setting { 'configured AllowUsers':
      ensure            => present,
      path              => '/etc/ssh/sshd_config',
      key_val_separator => ' ',
      setting           => 'AllowUsers',
      value             => $allow_users.join(' '),
      require           => Linux_secured_setup["ssh_access_is_limited on ${title}"],
    }
  }

  if $allow_groups != undef {
    ini_setting { 'configured AllowGroups':
      ensure            => present,
      path              => '/etc/ssh/sshd_config',
      key_val_separator => ' ',
      setting           => 'AllowGroups',
      value             => $allow_users.join(' '),
      require           => Linux_secured_setup["ssh_access_is_limited on ${title}"],
    }
  }

  if $deny_users != undef {
    ini_setting { 'configured DenyUsers':
      ensure            => present,
      path              => '/etc/ssh/sshd_config',
      key_val_separator => ' ',
      setting           => 'DenyUsers',
      value             => $deny_users.join(' '),
      require           => Linux_secured_setup["ssh_access_is_limited on ${title}"],
    }
  }

  if $deny_groups != undef {
    ini_setting { 'configured DenyGroups':
      ensure            => present,
      path              => '/etc/ssh/sshd_config',
      key_val_separator => ' ',
      setting           => 'DenyGroups',
      value             => $deny_users.join(' '),
      require           => Linux_secured_setup["ssh_access_is_limited on ${title}"],
    }
  }
}
