#
# linux_secured::controls::wireless_interfaces_are_disabled
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlWireless networking is used when wired networks are unavailable.## RationaleIf wireless is not to be used, wireless devices should be disabled to reduce the potential attack surface.## ImpactMany if not all laptop workstations and some desktop workstations will connect via wireless requiring these interfaces be enabled.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `linux_secured::controls::wireless_interfaces_are_disabled: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `wireless_interfaces_are_disabled` to the array value `linux_secured::skip_list` in your hiera data.  ## Excelent Compliance Solution.Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggesttaking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. Plus, our team can help you get up and running so that you can focus on other areas of your business. What are you waiting for? [Get started today!](/company/contact/)## BenchmarksThis control is used in the following benchmarks:- [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 3.1.4- [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 3.1.4
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::controls::wireless_interfaces_are_disabled () {
  # lint:ignore:strict_indent
  $validate_script = @(SCRIPT)
    #!/usr/bin/env bash

    {
      if command -v nmcli >/dev/null 2>&1 ; then
          if nmcli radio all | grep -Eq '\s*\S+\s+disabled\s+\S+\s+disabled\b'; then
            echo "Wireless is not enabled"
          else 
            nmcli radio all
          fi
      elif [ -n "$(find /sys/class/net/*/ -type d -name wireless)" ]; then
          t=0
          mname=$(for driverdir in $(find /sys/class/net/*/ -type d -name wireless | xargs -0 dirname); do basename "$(readlink -f "$driverdir"/device/driver/module)";done | sort -u)
          for dm in $mname; do
            if grep -Eq "^\s*install\s+$dm\s+/bin/(true|false)" /etc/modprobe.d/*.conf; then
                /bin/true
            else
                echo "$dm is not disabled"
                t=1
            fi
          done
          [ "$t" -eq 0 ] && echo "Wireless is not enabled"
      else
          echo "Wireless is not enabled"
      fi
    } | grep 'Wireless is not enabled'
    | SCRIPT

  $resolve_script = @(SCRIPT)
    #!/usr/bin/env bash

    {
      if command -v nmcli >/dev/null 2>&1 ; then
          nmcli radio all off
      else
          if [ -n "$(find /sys/class/net/*/ -type d -name wireless)" ]; then
            mname=$(for driverdir in $(find /sys/class/net/*/ -type d -name wireless | xargs -0 dirname); do basename "$(readlink -f "$driverdir"/device/driver/module)";done | sort -u)
            for dm in $mname; do
                echo "install $dm /bin/true" >> /etc/modprobe.d/disable_wireless.conf
            done
          fi
      fi
    }
    | SCRIPT
  # lint:endignore:strict_indent

  linux_secured_setup { "wireless_interfaces_are_disabled on ${title}":
    ensure => 'present',
  }

  -> exec { 'Disable wireless adapters':
    command => "/bin/bash ${resolve_script}",
    unless  => "/bin/bash ${validate_script}",
  }
}
