#
# linux_secured::ensure_cis
#
# @summary defined type `linux_secured::ensure_cis`
# Apply a specfied profile of the CIS benchmark to your system
# 
# Here is an example showing how to enable the CIS bencgmark for your system.:
# 
# ``` puppet
# linux_secured::ensure_cis { 'host':
#   product_version => 'redhat_el8',
#   doc_version     => 'V1.1.0',
#   profile         => 'level-1-server',
# }
# ```
# 
# When you don't specify the `doc_version`, puppet automatically uses the latest version for your current `product_version`. If you also don't specify a `product_version`, Puppet will detect the vcurrent version
# 
# When you want to skip certain controls, you can use the `skip_list`.
# 
# ``` puppet
# linux_secured::ensure_cis { 'host':
#   product_version => 'redhat_el8',
#   doc_version     => 'V1.1.0',
#   skip_list       => [
#     'noexec_option_set_on_var_partition',
#     'nosuid_option_set_on_var_partition',
#     'separate_partition_exists_for_var_tmp',
#   ]
# }
# ```
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
# @param [Optional[String[1]]] product_version
#    The system version of the CIS benchmark you want to apply.
#    Although not very logical, you **can** apply an older (or newer) system version to your system.
#    If you also don't specify a `product_version`, Puppet will detect the version of Linux running and use this to determine the `product_version`.
#
# @param [Optional[String[1]]] doc_version
#    The version of the CIS benchmark you want to apply to your system.
#    When you don't specify the `doc_version`, puppet automatically uses the latest version for your current `product_version`.
#
# @param all_controls
#    This is an internal parameter.
#    This is the Hash containing all paragraphs from the selected CIS benchmark.
#
# @param [Array] skip_list
#    This is the list of controls that you want to skip.
#    By default this vale is empty, meaning `linux_secured` will apply **ALL** controls. You must specifiy the name of the control. Here is an example on how to do this:
#        linux_secured { 'host':
#          product_version  => 'redhat_el8',
#          doc_version => 'V2.0.0',
#          skip_list   => [
#            'noexec_option_set_on_var_partition',
#            'nosuid_option_set_on_var_partition',
#            'separate_partition_exists_for_var_tmp',
#          ]
#        }
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::ensure_cis (
  Optional[String[1]]  $product_version = linux_secured::default_product_version($title),
  Optional[String[1]]  $doc_version     = linux_secured::default_doc_version($product_version, 'cis'),
  Optional[String[1]]  $profile         = linux_secured::lookup_setting('profile', 'level-1-server'),
  Array                $skip_list       = linux_secured::lookup_setting('skip_list', []),
  Optional[String[1]]  $use_schedule    = linux_secured::lookup_setting('use_schedule', undef),
  Easy_type::Operation $operation       = linux_secured::lookup_setting('operation','enforce'),
  Easy_type::Report_as $report_as       = 'warning',
) {
  include linux_secured::fact_caching
  easy_type::secure::ensure_benchmark { $title:
    benchmark       => 'cis',
    product_version => $product_version,
    doc_version     => $doc_version,
    operation       => $operation,
    profile         => $profile,
    skip_list       => $skip_list,
    report_as       => $report_as,
    use_schedule    => $use_schedule,
  }
}
