#
# linux_secured::ensure_set
#
# @summary defined type `linux_secured::ensure_set`
# With this defined type, you can select a subset of the CIS controls to ensure_set to your system. Currently only the set `BASIC` is predefined. 
# You can also define your own sets. See [here](/docs/linux_secured/define_sets.html) on how to define your own levels.
# 
# Here is an example on how to use this:
# 
# ```
# linux_secured::ensure_set {'host':
#   product_version => 'redhat_el8',
#   doc_version     => 'V1.1.0',
#   set             => 'BASIC'
# }
# ```
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
# @param [Optional[String[1]]] product_version
#    The system version of the CIS benchmark you want to apply.
#    Although not very logical, you **can** apply an older (or newer) system version to your system.
#    If you also don't specify a `product_version`, Puppet will detect the version of Linux running and use this to determine the `product_version`.
#
# @param [Optional[String[1]]] doc_version
#    The version of the CIS benchmark you want to apply to your system.
#    When you don't specify the `doc_version`, puppet automatically uses the latest version for your current `product_version`.
#
# @param [String[1]] set
#    With this parameter, you can specify the set of CIS controls you want to apply to your system.
#    Currently, we have the following sets predefined:
#    - ALL
#    - BASIC
#    - AUDIT_ONLY
#    Check [here](/docs/linux_secured/predefined_sets.md) for a description of the predefined sets.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::ensure_set (
  String[1]                  $set             = 'BASIC',
  Easy_type::Baseline_type   $benchmark       = 'cis',
  Optional[String[1]]        $product_version = linux_secured::default_product_version($title),
  Optional[String[1]]        $doc_version     = linux_secured::default_doc_version($product_version, $benchmark),
  Easy_type::Operation       $operation       = linux_secured::lookup_setting('operation','enforce'),
  Easy_type::Report_as       $report_as       = 'warning',
) {
  easy_type::secure::ensure_set { $title:
    benchmark       => $benchmark,
    set             => $set,
    product_version => $product_version,
    operation       => $operation,
    doc_version     => $doc_version,
    report_as       => $report_as,
  }
}
