#
# linux_secured::ensure_stig
#
# @summary defined type `linux_secured`
# Apply **all** Linux system CIS control to the specified system
# 
# Here is an example showing how to enable the CIS bencgmark for your system.:
# 
# ``` puppet
# linux_secured::ensure_stig { 'host':
#   product_version  => 'redhat_el8',
#   doc_version => 'V1.1.0',
# }
# ```
# 
# When you don't specify the `doc_version`, puppet automatically uses the latest version for your current `product_version`. If you also don't specify a `product_version`, Puppet will detect the version of Linux running and use this to determine the `product_version`. There is, however, one issue with the detection. On an initial run Puppet canot determine what the Linux version is. In that case, the linux_secured::ensure_stig defined type will skip applying the CIS benchmark and wait until (hopefully) the next run the version of Linux for specified sid is available.
# 
# When you want to skip certain controls, you can use the `skip_list`.
# 
# ``` puppet
# linux_secured::ensure_stig { 'host':
#   product_version => 'redhat_el8',
#   doc_version     => 'V1.1.0',
#   skip_list       => [
#     'alter_system_link_action_audit_is_enabled',
#     'alter_role_action_audit_is_enabled',
#   ]
# }
# ```
# 
# When you have multiple system on your system and want to use the same system version and CIS document version, you can do this:
# 
# ``` puppet
# linux_secured::Ensure_stig {
#   product_version => 'redhat_el8',
#   doc_version     => 'V1.1.0',
#   skip_list       => [
#     'alter_system_link_action_audit_is_enabled',
#     'alter_role_action_audit_is_enabled',
#   ]
# }
# 
# linux_secured::ensure_stig {'DB1':}
# linux_secured::ensure_stig {'Linux':}
# ```
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
# @param [Optional[String[1]]] product_version
#    The system version of the CIS benchmark you want to apply.
#    Although not very logical, you **can** apply an older (or newer) system version to your system.
#    If you also don't specify a `product_version`, Puppet will detect the version of Linux running and use this to determine the `product_version`. There is, however, one issue with the detection. On an initial run Puppet canot determine what the Linux version is. In that case, the linux_secured defined type will skip applying the CIS benchmark and wait until (hopefully) the next run the version of Linux for specified sid is available.
#
# @param [Optional[String[1]]] doc_version
#    The version of the CIS benchmark you want to apply to your system.
#    When you don't specify the `doc_version`, puppet automatically uses the latest version for your current `product_version`.
#
# @param all_controls
#    This is an internal parameter.
#    This is the Hash containing all paragraphs from the selected CIS benchmark.
#
# @param nonpdb_controls
#    This is an internal parameter.
#    It contains all of the controls that don't run on a pluggable system.
#
# @param [Array] skip_list
#    This is the list of controls that you want to skip.
#    By default this vale is empty, meaning `linux_secured` will apply **ALL** controls. You must specifiy the name of the control. Here is an example on how to do this:
#        linux_secured { 'MYDB':
#          product_version  => 'db19c',
#          doc_version => 'V1.0.0',
#          skip_list   => [
#            'alter_system_link_action_audit_is_enabled',
#            'alter_role_action_audit_is_enabled',
#          ]
#        }
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::ensure_stig (
  Optional[String[1]]                 $product_version = linux_secured::default_product_version($title),
  Optional[String[1]]                 $doc_version     = linux_secured::default_doc_version($product_version, 'stig'),
  Enum['enforce','validate', 'both']  $operation = 'enforce',
  Array                               $skip_list       = [],
) {
  easy_type::secure::ensure_benchmark { $title:
    benchmark       => 'stig',
    product_version => $product_version,
    doc_version     => $doc_version,
    operation       => $operation,
    skip_list       => $skip_list,
  }
}
