#
# linux_secured::validators::access_to_the_su_command_is_restricted
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `su` command allows a user to run a command or shell as another
# user. The program has been superseded by sudo, which allows for more granular
# control over privileged access. Normally, the su command can be executed by any
# user. By uncommenting the `pam_wheel.so` statement in `/etc/pam.d/su`, the `su`
# command will only allow users in a specific groups to execute su. This group should
# be empty to reinforce the use of sudo for privileged access.
# 
# 
# ## Rationale
# 
# Restricting the use of `su` , and using `sudo` in its place, provides system administrators better control of the escalation of user privileges to execute privileged commands. The `sudo` utility also provides a better logging and audit mechanism, as it can log each command executed via `sudo` , whereas su can only record that a user executed the `su` program.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::access_to_the_su_command_is_restricted: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `access_to_the_su_command_is_restricted` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.3.7
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.3.7
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::access_to_the_su_command_is_restricted (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "access_to_the_su_command_is_restricted validation on ${title}":
    ensure => 'present',
  }

  -> validation { "access to the su command is restricted on ${title}":
    check           => 'puppet facts restricted_sudo_group',
    path            => ['/usr/sbin/', '/usr/bin', '/opt/puppetlabs/bin'],
    expected_output => /true/,
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "access to the su command should be restricted on ${title}, but it is NOT",
  }
}
