#
# linux_secured::validators::authentication_is_required_when_booting_into_rescue_mode
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# Rescue mode (former single user mode) is used for recovery when the
# system detects an issue during boot or by manual selection from the bootloader.
# 
# 
# ## Rationale
# 
# Requiring authentication in rescue mode (former single user mode) prevents an unauthorized user from rebooting the system into rescue mode to gain root privileges without credentials.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::authentication_is_required_when_booting_into_rescue_mode: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `authentication_is_required_when_booting_into_rescue_mode` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 1.4.3
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 1.4.3
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::authentication_is_required_when_booting_into_rescue_mode (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "authentication_is_required_when_booting_into_rescue_mode validation on ${title}":
    ensure => 'present',
  }

  -> validation { "authentication is required when booting into rescue mode on ${title}":
    check           => 'grep -r /systemd-sulogin-shell /usr/lib/systemd/system/rescue.service',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => Regexp('ExecStart=-/usr/lib/systemd/systemd-sulogin-shell rescue'),
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "authentication should be required when booting into rescue mode on ${title}, but it is NOT",
  }
}
