#
# linux_secured::validators::changes_to_system_administration_scope_sudoers_is_collected
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# Monitor scope changes for system administrators. If the system has
# been properly configured to force system administrators to log in as themselves
# first and then use the sudo command to execute privileged commands, it is possible
# to monitor changes in scope. The file `/etc/sudoers`, or files in `/etc/sudoers.d`,
# will be written to when the file(s) or related attributes have changed. The audit
# records will be tagged with the identifier \"scope\".
# 
# 
# ## Rationale
# 
# Changes in the `/etc/sudoers` and `/etc/sudoers.d` files can indicate that an unauthorized change has been made to the scope of system administrator activity.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::changes_to_system_administration_scope_sudoers_is_collected: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `changes_to_system_administration_scope_sudoers_is_collected` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 4.1.3.1
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 4.1.3.1
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::changes_to_system_administration_scope_sudoers_is_collected (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "changes_to_system_administration_scope_sudoers_is_collected validation on ${title}":
    ensure => 'present',
  }

  -> validation { "changes to system administration scope (sudoers) is collected on ${title}":
    check           => "auditctl -l | awk '/^ *-w/ && /\\/etc\\/sudoers/ &&/ +-p *wa/ &&(/ key= *[!-~]* *$/||/ -k *[!-~]* *$/)'",
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => Regexp('-w /etc/sudoers -p wa -k scope\n-w /etc/sudoers.d -p wa -k scope'),
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "changes to system administration scope should be collected on ${title}, but it is NOT",
    require         => Exec['refresh audit deamon'],
  }
  include linux_secured::internal::refresh_audit_daemon
}
