#
# linux_secured::validators::default_user_umask_is_027_or_more_restrictive
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The user file-creation mode mask (`umask`) is use to determine the file permission for newly created directories and files. In Linux, the default permissions for any newly created directory is 0777 (r`wxrwxrwx`), and for any newly created file it is 0666 (`rw-rw-rw-`). The `umask` modifies the default Linux permissions by restricting (masking) these permissions. The `umask` is not simply subtracted, but is processed bitwise. Bits set in the umask are cleared in the resulting file mode.
# `umask` can be set with either octal or Symbolic values:
# - Octal (Numeric) Value - Represented by either three or four digits. ie `umask` `0027` or `umask` `027`. If a four digit `umask` is used, the first digit is ignored. The remaining three digits effect the resulting permissions for user, group, and world/other respectively.
# - Symbolic Value - Represented by a comma separated list for User `u`, group `g`, and world/other `o`. The permissions listed are not masked by `umask`. ie a `umask` set by `umask` `u=rwx,g=rx,o=` is the Symbolic equivalent of the Octal `umask` `027`. This umask would set a newly created directory with file mode `drwxr-x---` and a newly created file with file mode `rw-r-----`.
# The default `umask` can be set to use the `pam_umask` module or in a System Wide Shell Configuration File. The user creating the directories or files has the discretion of changing the permissions via the chmod command, or choosing a different default umask by adding the umask command into a User Shell Configuration File, ( `.bash_profile` or `.bashrc`), in their home directory.
# 
# Setting the default umask:
# - `pam_umask` module:
#   - will set the umask according to the system default in `/etc/login.defs` and
# user settings, solving the problem of different umask settings with different
# shells, display managers, remote sessions etc.
#   - `umask=<mask>` value in the `/etc/login.defs` file is interpreted as Octal o Setting `USERGROUPS_ENAB` to yes in `/etc/login.defs` (default):
#     - will enable setting of the umask group bits to be the same as owner bits. (examples: `022` -> `002`, `077` -> `007`) for non-root users, if the uid
# is the same as `gid`, and `username` is the same as the `<primary group name>`
#     - `userdel` will remove the user's group if it contains no more members, and useradd will create by default a group with the name of the user
# - System Wide Shell Configuration File:
#   - `/etc/profile` - used to set system wide environmental variables on users
# shells. The variables are sometimes the same ones that are in the .bash_profile, however this file is used to set an initial PATH or PS1 for all shell users of the system. is only executed for interactive login shells, or shells executed with the --login parameter.
#   - `/etc/profile.d` - `/etc/profile` will execute the scripts within `/etc/profile.d/*.sh`. It is recommended to place your configuration in a shell script within `/etc/profile.d` to set your own system wide environmental variables.
#   - `/etc/bashrc` - System wide version of .bashrc. In Fedora derived distributions, `/etc/bashrc` also invokes `/etc/profile.d/*.sh` if non-login shell, but redirects output to /dev/null if non-interactive. Is only executed for interactive shells or if `BASH_ENV` is set to `/etc/bashrc`.
# 
# User Shell Configuration Files:
# 
# - `~/.bash_profile` - Is executed to configure your shell before the initial command prompt. Is only read by login shells.
# - `~/.bashrc` - Is executed for interactive shells. only read by a shell that's both interactive and non-login
# 
# 
# ## Rationale
# 
# Setting a secure default value for umask ensures that users make a conscious choice about their file permissions. A permissive umask value could result in directories or files with excessive permissions that can be read and/or written to by unauthorized users.
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::default_user_umask_is_027_or_more_restrictive: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `default_user_umask_is_027_or_more_restrictive` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.6.5
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.6.5
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::default_user_umask_is_027_or_more_restrictive (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  #lint:ignore:strict_indent
  $script = @(CODE)
  #!/bin/bash
  passing=""
  grep -Eiq '^\s*UMASK\s+(0[0-7][2-7]7|[0-7][2-7]7)\b' /etc/login.defs && grep -Eqi '^\s*USERGROUPS_ENAB\s*"?no"?\b' /etc/login.defs && grep -Eq '^\s*session\s+(optional|requisite|required)\s+pam_umask\.so\b' /etc/pam.d/common-session && passing=true
  grep -REiq '^\s*UMASK\s+\s*(0[0-7][2-7]7|[0-7][2-7]7|u=(r?|w?|x?)(r?|w?|x?)(r?|w?|x?),g=(r?x?|x?r?),o=)\b' /etc/profile* /etc/bashrc* && passing=true
  [ "$passing" = true ] && echo "Default user umask is set"
  | CODE
  #lint:endignore:strict_indent

  linux_secured_setup { "default_user_umask_is_027_or_more_restrictive validation on ${title}":
    ensure => 'present',
  }

  -> validation { "default user umask is set on ${title}":
    check           => "bash ${script}",
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => "Default user umask is set\n",
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "default user umask should be 027 or more restrictive on ${title}, but it is NOT",
  }

  # TODO: Implement this
  # -> validation { "default user umask is 027 or more restrictive on ${title}":
  #   check           => @(SCRIPT),
  #   grep -RPi '(^|^[^#]*)\s*umask\s+([0-7][0-7][01][0-7]\b|[0-7][0-7][0-7][0-6]\b|[0-7][01][0-7]\b|[0-7][0-7][0-6]\b|(u=[rwx]{0,3},)?(g=[rwx]{0,3},)?o=[rwx]+\b|(u=[rwx]{1,3},)?g=[^rx]{1,3}(,o=[rwx]{0,3})?\b)' /etc/login.defs /etc/profile* /etc/bashrc*
  #   | SCRIPT
  #   path            => ['/usr/sbin/', '/usr/bin'],
  #   expected_output => "Default user umask is set\n",
  #   report_as       => $report_as,
  # skip                => $skip,
  #   control         => easy_type::current_control(),
  #   fail_message    => "default user umask should be 027 or more restrictive on ${title}, but it is NOT",
  # }
}
