#
# linux_secured::validators::events_that_modify_the_systems_mandatory_access_controls_are_collected
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# Monitor SELinux, an implementation of mandatory access controls. The parameters below monitor any write access (potential additional, deletion or modification of files in the directory) or attribute changes to the `/etc/selinux/` and /`usr/share/selinux/` directories.
# Note: If a different Mandatory Access Control method is used, changes to the corresponding directories should be audited.
# 
# 
# ## Rationale
# 
# Changes to files in the `/etc/selinux/` and `/usr/share/selinux/` directories could indicate that an unauthorized user is attempting to modify access controls and change security contexts, leading to a compromise of the system.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::events_that_modify_the_systems_mandatory_access_controls_are_collected: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `events_that_modify_the_systems_mandatory_access_controls_are_collected` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 4.1.3.14
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 4.1.3.14
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::events_that_modify_the_systems_mandatory_access_controls_are_collected (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "events_that_modify_the_systems_mandatory_access_controls_are_collected validation on ${title}":
    ensure => 'present',
  }

  -> validation { "events that modify the system's Mandatory Access Controls are collected on ${title}":
    check           => 'auditctl -l',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => [
      Regexp('-w /etc/selinux -p wa -k MAC-policy'),
      Regexp('-w /usr/share/selinux -p wa -k MAC-policy'),
    ],
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "events that modify the system's Mandatory Access Controls should be collected on ${title}, but they are NOT",
    require         => Exec['refresh audit deamon'],
  }
  include linux_secured::internal::refresh_audit_daemon
}
