#
# linux_secured::validators::events_that_modify_the_systems_network_environment_are_collected
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# Record changes to network environment files or system calls. The below parameters monitor the following system calls, and write an audit event on system call exit:
# 
# - `sethostname` - set the systems host name
# - `setdomainname` - set the systems domain name
# 
# The files being monitored are:
# 
# - `/etc/issue` and `/etc/issue.net` - messages displayed pre-login
# - `/etc/hosts` - file containing host names and associated IP addresses
# - `/etc/sysconfig/network` - additional information that is valid to all network interfaces
# - `/etc/sysconfig/network-scripts/` - directory containing network interface scripts and configurations files
# 
# 
# ## Rationale
# 
# Monitoring sethostname and setdomainname will identify potential unauthorized changes to host and domainname of a system. The changing of these names could potentially break security parameters that are set based on those names. The `/etc/hosts` file is monitored for changes that can indicate an unauthorized intruder is trying to change machine associations with IP addresses and trick users and processes into connecting to unintended machines. Monitoring `/etc/issue` and /`etc/issue.net` is important, as intruders could put disinformation into those files and trick users into providing information to the intruder. Monitoring `/etc/sysconfig/network` is important as it can show if network interfaces or scripts are being modified in a way that can lead to the machine becoming unavailable or compromised. All audit records should have a relevant tag associated with them.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::events_that_modify_the_systems_network_environment_are_collected: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `events_that_modify_the_systems_network_environment_are_collected` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 4.1.3.5
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 4.1.3.5
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::events_that_modify_the_systems_network_environment_are_collected (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "events_that_modify_the_systems_network_environment_are_collected validation on ${title}":
    ensure => 'present',
  }

  -> validation { "events that modify the system's network environment are collected on ${title}":
    check           => 'auditctl -l',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => [
      Regexp('-a always,exit -F arch=b64 -S sethostname,setdomainname -F key=system-locale'),
      Regexp('-a always,exit -F arch=b32 -S sethostname,setdomainname -F key=system-locale'),
      Regexp('-w /etc/issue -p wa -k system-locale'),
      Regexp('-w /etc/issue.net -p wa -k system-locale'),
      Regexp('-w /etc/hosts -p wa -k system-locale'),
      Regexp('-w /etc/sysconfig/network -p wa -k system-locale'),
      Regexp('-w /etc/sysconfig/network-scripts -p wa -k system-locale'),
    ],
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "events that modify the system's network environment should be collected on ${title}, but they are NOT",
    require         => Exec['refresh audit deamon'],
  }
  include linux_secured::internal::refresh_audit_daemon
}
