#
# linux_secured::validators::filesystem_integrity_is_regularly_checked
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# Periodic checking of the filesystem integrity is needed to detect
# changes to the filesystem.
# 
# 
# ## Rationale
# 
# Periodic file checking allows the system administrator to determine on a regular basis if critical files have been changed in an unauthorized fashion.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::filesystem_integrity_is_regularly_checked: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `filesystem_integrity_is_regularly_checked` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 1.3.2
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 1.3.2
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::filesystem_integrity_is_regularly_checked (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "filesystem_integrity_is_regularly_checked validation on ${title}":
    ensure => 'present',
  }

  -> validation { "aidecheck service is enabled on ${title}":
    check           => 'systemctl is-enabled aidecheck.service',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => /enabled/,
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "aidecheck service should be enabled on ${title}, and it is NOT",
  }

  -> validation { "aidecheck timer is enabled on ${title}":
    check           => 'systemctl is-enabled aidecheck.timer',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => /enabled/,
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "aidecheck timer should be enabled on ${title}, and it is NOT",
  }

  -> validation { "aidecheck timer is active on ${title}":
    check           => 'systemctl status aidecheck.timer | grep Active:',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => Regexp('^active'),
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "aidecheck timer should be active on ${title}, and it is NOT",
  }
}
