#
# linux_secured::validators::firewalld_default_zone_is_set
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# A firewall zone defines the trust level for a connection, interface or source address binding. This is a one to many relation, which means that a connection, interface or source can only be part of one zone, but a zone can be used for many network connections, interfaces and sources.
# - The default zone is the zone that is used for everything that is not explicitly bound/assigned to another zone.
# Connections handled by NetworkManager are listed as NetworkManager requests to add the zone binding for the interface used by the connection. Also interfaces under control of the network service are listed also because the service requests it.
# 
# 
# **Note**:
# - A firewalld zone configuration file contains the information for a zone.    o These are the zone description, services, ports, protocols, icmp-blocks,
# masquerade, forward-ports and rich language rules in an XML file format.
# o The file name has to be zone_name.xml where length of zone_name is currently
# limited to 17 chars.
# - NetworkManager binds interfaces to zones automatically
# 
# 
# ## Rationale
# 
# Because the default zone is the zone that is used for everything that is not explicitly bound/assigned to another zone, it is important for the default zone to set
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::firewalld_default_zone_is_set: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `firewalld_default_zone_is_set` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 3.4.1.5
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 3.4.1.5
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::firewalld_default_zone_is_set (
  Boolean   $skip         = linux_secured::lookup_setting('skip', false),
  String[1] $report_as    = linux_secured::lookup_setting('report_as', 'warning'),
  String[1] $default_zone = linux_secured::lookup_setting('default_zone', 'public'),
) {
  linux_secured_setup { "firewalld_default_zone_is_set validation on ${title}":
    ensure => 'present',
  }

  -> validation { "firewalld default zone is set on ${title}":
    check           => 'firewall-cmd --get-default-zone',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => Regexp($default_zone),
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "firewalld default zone should be set on ${title}, but it is NOT",
  }
}
