#
# linux_secured::validators::firewalld_is_either_not_installed_or_masked_with_iptables
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# firewalld (Dynamic Firewall Manager) provides a dynamically managed
# firewall with support for network/firewall “zones” to assign a level of trust
# to a network and its associated connections, interfaces or sources. It has support
# for IPv4, IPv6, Ethernet bridges and also for IPSet firewall settings. There is
# a separation of the runtime and permanent configuration options.
# 
# 
# ## Rationale
# 
# Running `iptables.service` and\or `ip6tables.service` with `firewalld.service` may lead to conflict and unexpected results.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::firewalld_is_either_not_installed_or_masked_with_iptables: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `firewalld_is_either_not_installed_or_masked_with_iptables` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 3.4.3.1.3
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 3.4.3.1.3
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::firewalld_is_either_not_installed_or_masked_with_iptables (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "firewalld_is_either_not_installed_or_masked_with_iptables validation on ${title}":
    ensure => 'present',
  }

  -> validation { "firewalld is not running with iptables on ${title}":
    check           => 'systemctl status firewalld | grep "Active: " | grep  "active (running)"',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => '',
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "firewalld should NOT be running on ${title}, but it IS",
  }

  -> validation { "firewalld is masked with iptables on ${title}":
    check           => 'systemctl is-enabled firewalld',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => /masked/,
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "firewalld should be masked on ${title}, but it is NOT",
  }
}
