#
# linux_secured::validators::gdm_login_banner_is_configured
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# GDM is the GNOME Display Manager which handles graphical login for
# GNOME based systems.
# 
# 
# ## Rationale
# 
# Warning messages inform users who are attempting to login to the system of their legal status regarding the system and must include the name of the organization that owns the system and any monitoring policies that are in place.
# Note: If a graphical login is not required, it should be removed to reduce the attack surface of the system.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::gdm_login_banner_is_configured: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `gdm_login_banner_is_configured` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 1.8.2
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 1.8.2
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::gdm_login_banner_is_configured (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "gdm_login_banner_is_configured validation on ${title}":
    ensure => 'present',
  }

  -> validation { "GDM login banner is configured on ${title}":
    check           => 'cat /etc/dconf/profile/gdm',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => [
      /user-db:user/,
      /system-db:gdm/,
      Regexp('file-db:/usr/share/gdm/greeter-dconf-defaults'),
    ],
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "GDM login banner should be configured on ${title}, but it is NOT",
  }

  -> validation { "GDM banner message is configured on ${title}":
    check           => 'cat /etc/dconf/db/gdm.d/01-banner-message',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => [
      Regexp('[org/gnome/login-screen]'),
      Regexp('banner-message-enable=true'),
      Regexp('banner-message-text=\''),
    ],
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "GDM banner message should be configured on ${title}, but it is NOT",
  }
}
