#
# linux_secured::validators::gpgcheck_is_globally_activated
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The gpgcheck option, found in the main section of the `/etc/dnf/dnf.conf`
# and individual `/etc/yum.repos.d/*` files, determines if an RPM package's signature
# is checked prior to its installation.
# 
# 
# ## Rationale
# 
# It is important to ensure that an RPM's package signature is always checked prior to installation to ensure that the software is obtained from a trusted source.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::gpgcheck_is_globally_activated: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `gpgcheck_is_globally_activated` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 1.2.2
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 1.2.3
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::gpgcheck_is_globally_activated (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "gpgcheck_is_globally_activated validation on ${title}":
    ensure => 'present',
  }

  validation { "GPG check is enabled for dnf on ${title}":
    check           => 'grep ^gpgcheck /etc/dnf/dnf.conf',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => /gpgcheck=1/,
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "GPG check should be enabled on ${title}, but it is NOT ",
  }

  validation { "GPG check is enabled for all repos on ${title}":
    check           => 'grep -P "^gpgcheck\h*=\h*[^1].*\h*$" /etc/yum.repos.d/*',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => '',
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "GPG check should be enabled on all repos on ${title}, but it is NOT",
  }
}
