#
# linux_secured::validators::icmp_redirects_are_not_accepted
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# ICMP redirect messages are packets that convey routing information
# and tell your host (acting as a router) to send packets via an alternate path.
# It is a way of allowing an outside routing device to update your system routing
# tables. By setting `net.ipv4.conf.all.accept_redirects` and `net.ipv6.conf.all.accept_redirects
# `to `0,` the system will not accept any ICMP redirect messages, and therefore,
# won't allow outsiders to update the system's routing tables.
# 
# 
# ## Rationale
# 
# Attackers could use bogus ICMP redirect messages to maliciously alter the system routing tables and get them to send packets
# to incorrect networks and allow your system packets to be captured.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::icmp_redirects_are_not_accepted: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `icmp_redirects_are_not_accepted` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 3.3.2
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 3.3.2
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::icmp_redirects_are_not_accepted (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "icmp_redirects_are_not_accepted validation on ${title}":
    ensure => 'present',
  }

  -> validation { "IPV4 all ICMP redirects are not accepted on ${title}":
    check           => "bash ${linux_secured::sysctl_value('net.ipv4.conf.all.accept_redirects', '0')}",
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => /PASS/,
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "IPV4 all ICMP redirects should NOT be accepted on ${title}, but it IS",
    require         => Linux_secured_setup["icmp_redirects_are_not_accepted validation on ${title}"],
  }

  -> validation { "IPV4 default ICMP redirects are not accepted on ${title}":
    check           => "bash ${linux_secured::sysctl_value('net.ipv4.conf.default.accept_redirects', '0')}",
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => /PASS/,
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "IPV4 default ICMP redirects should NOT be accepted on ${title}, but it IS",
    require         => Linux_secured_setup["icmp_redirects_are_not_accepted validation on ${title}"],
  }

  if $facts['ip6_enabled'] == true {
    validation { "IPV6 all ICMP redirects are not accepted on ${title}":
      check           => "bash ${linux_secured::sysctl_value('net.ipv6.conf.all.accept_redirects', '0')}",
      path            => ['/usr/sbin/', '/usr/bin'],
      expected_output => /PASS/,
      report_as       => $report_as,
      skip            => $skip,
      control         => easy_type::current_control(),
      fail_message    => "IPV6 all ICMP redirects should NOT be accepted on ${title}, but it IS",
      require         => Linux_secured_setup["icmp_redirects_are_not_accepted validation on ${title}"],
    }

    -> validation { "IPV6 default ICMP redirects are not accepted on ${title}":
      check           => "bash ${linux_secured::sysctl_value('net.ipv6.conf.default.accept_redirects', '0')}",
      path            => ['/usr/sbin/', '/usr/bin'],
      expected_output => /PASS/,
      report_as       => $report_as,
      skip            => $skip,
      control         => easy_type::current_control(),
      fail_message    => "IPV6 default ICMP redirects should NOT be accepted on ${title}, but it IS",
      require         => Linux_secured_setup["icmp_redirects_are_not_accepted validation on ${title}"],
    }
  }
}
