#
# linux_secured::validators::inactive_password_lock_is_30_days_or_less
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# User accounts that have been inactive for over a given period of time
# can be automatically disabled. It is recommended that accounts that are inactive
# for 30 days after password expiration be disabled.
# 
# 
# ## Rationale
# 
# Inactive accounts pose a threat to system security since the users are not logging in to notice failed login attempts or other anomalies.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::inactive_password_lock_is_30_days_or_less: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `inactive_password_lock_is_30_days_or_less` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.6.1.4
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.6.1.4
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::inactive_password_lock_is_30_days_or_less (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "inactive_password_lock_is_30_days_or_less validation on ${title}":
    ensure => 'present',
  }

  -> validation { "inactive password lock policy is 30 days or less on ${title}":
    check          => 'useradd -D | grep INACTIVE',
    path           => ['/usr/sbin/', '/usr/bin'],
    parse_value    => Regexp('\w+=(.*)'),
    expected_value => [
      '<= 30',
      '> 0',
    ],
    report_as      => $report_as,
    skip           => $skip,
    control        => easy_type::current_control(),
    fail_message   => "inactive password lock policy should be 30 days or on ${title}, but it is NOT",
  }

  -> validation { "inactive password lock for users is 30 days or less on ${title}":
    check           => 'puppet facts users_with_long_lock_periode',
    path            => ['/usr/sbin/', '/usr/bin', '/opt/puppetlabs/bin'],
    expected_output => Regexp('[\n\n  ]\n'),
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "inactive password lock for users should be 30 days or less on ${title}, but it is NOT",
  }
}
