#
# linux_secured::validators::ip6tables_default_deny_firewall_policy
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# A default deny all policy on connections ensures that any unconfigured
# network usage will be rejected.
# 
# 
# ## Rationale
# 
# With a default accept policy the firewall will accept any packet that is not configured to be denied. It is easier to white list acceptable usage than to black list unacceptable usage.
# 
# 
# **Note**: Changing firewall settings while connected over network can result in being locked out of the system.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::ip6tables_default_deny_firewall_policy: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `ip6tables_default_deny_firewall_policy` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 3.4.3.3.4
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 3.4.3.3.4
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::ip6tables_default_deny_firewall_policy (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "ip6tables_default_deny_firewall_policy validation on ${title}":
    ensure => 'present',
  }

  ['INPUT', 'OUTPUT', 'FORWARD'].each |$chain| {
    validation { "ip6tables default deny firewall policy for chain ${chain} on ${title}":
      check           => "ip6tables -L | grep 'Chain ${chain}'",
      path            => ['/usr/sbin/', '/usr/bin'],
      expected_output => /(policy DROP|REJECT)/,
      report_as       => $report_as,
      skip            => $skip,
      control         => easy_type::current_control(),
      fail_message    => "ip6tables should have a default deny policy for chain ${chain} on ${title}, but has is NOT",
      require         => Linux_secured_setup["ip6tables_default_deny_firewall_policy validation on ${title}"],
    }
  }
}
