#
# linux_secured::validators::ip6tables_loopback_traffic_is_configured
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# Configure the loopback interface to accept traffic. Configure all other interfaces to deny traffic to the loopback network (::1).
# 
# 
# ## Rationale
# 
# Loopback traffic is generated between processes on machine and is typically critical to operation of the system. 
# The loopback interface is the only place that loopback network (::1) traffic should be seen, all other interfaces 
# should ignore traffic on this network as an anti-spoofing measure.
# 
# 
# **Note**: Changing firewall settings while connected over network can result in being locked out of the system.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::ip6tables_loopback_traffic_is_configured: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `ip6tables_loopback_traffic_is_configured` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 3.4.3.3.1
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 3.4.3.3.1
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::ip6tables_loopback_traffic_is_configured (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "ip6tables_loopback_traffic_is_configured validation on ${title}":
    ensure => 'present',
  }

  -> validation { "IPv6 the loopback interface is configured to accept incomming traffic on ${title}":
    check           => 'ip6tables -L INPUT -v -n',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => /ACCEPT     all      lo     \*       ::\/0                 ::\/0/,
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "the IPv6 loopback interface should be configured to accept incomming traffic on ${title}, but it is NOT",
  }

  -> validation { "IPv6 all other interface are configured to drop traffic to the loopback network on ${title}":
    check           => 'ip6tables -L INPUT -v -n',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => /DROP       all      \*      \*       ::1                  ::\/0/,
    report_as       => $report_as,
    skip                => $skip,
    control            => easy_type::current_control(),
    fail_message    => "IPv6 All other interface should be configured to drop traffic to the loopback network on ${title}, but they are NOT",
  }

  -> validation { "IPv6 the loopback interface is configured to accept outgoing traffic on ${title}":
    check           => 'ip6tables -L OUTPUT -v -n',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => /ACCEPT     all      \*      lo      ::\/0                 ::\/0/,
    report_as       => $report_as,
    skip                => $skip,
    control            => easy_type::current_control(),
    fail_message    => "the IPv6 loopback interface should be configured to accept outgoing traffic on ${title}, but it is NOT",
  }
}
