#
# linux_secured::validators::kernel_module_loading_unloading_and_modification_is_collected
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# Monitor the loading and unloading of kernel modules. All the loading / listing / dependency checking of modules is done by kmod via symbolic links.
# The following system calls control loading and unloading of modules:
# - `init_module` - load a module
# - `finit_module` - load a module (used when the overhead of using cryptographicallysigned modules to determine the authenticity of a module can be avoided)
# - `delete_module` - delete a module
# - `create_module` - create a loadable module entry
# - `query_module` - query the kernel for various bits pertaining to modules
# 
# Any execution of the loading and unloading module programs and system calls will trigger an audit record with an identifier of modules.
# 
# 
# ## Rationale
# 
# Monitoring the use of all the various ways to manipulate kernel modules could provide system administrators with evidence that an unauthorized change was made to a kernel module, possibly compromising the security of the system.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::kernel_module_loading_unloading_and_modification_is_collected: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `kernel_module_loading_unloading_and_modification_is_collected` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 4.1.3.19
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 4.1.3.19
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::kernel_module_loading_unloading_and_modification_is_collected (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  $script = @(SCRIPT)
      bash S_LINKS=$(ls -l /usr/sbin/lsmod /usr/sbin/rmmod /usr/sbin/insmod /usr/sbin/modinfo /usr/sbin/modprobe /usr/sbin/depmod | grep -v " -> ../bin/kmod" || true) \
      && if [[ "${S_LINKS}" != "" ]]; then printf "Issue with symlinks: ${S_LINKS}\n"; else printf "OK\n"; fi
    | SCRIPT

  linux_secured_setup { "kernel_module_loading_unloading_and_modification_is_collected validation on ${title}":
    ensure => 'present',
  }

  -> validation { "kernel module loading unloading and modification is collected on ${title}":
    check           => 'auditctl -l',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => [
      Regexp("-a always,exit -F arch=b64 -S create_module,init_module,delete_module,query_module,finit_module -F auid>=${facts[uid_min]} -F auid!=-1 -F key=kernel_modules"),
      Regexp("-a always,exit -S all -F path=/usr/bin/kmod -F perm=x -F auid>=${facts[uid_min]} -F auid!=-1 -F key=kernel_modules"),
    ],
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "kernel module loading unloading and modification should be collected on ${title}, but they are NOT",
    require         => Exec['refresh audit deamon'],
  }

  -> validation { "the symlinks that kmod accepts is indeed pointing at it on ${title}":
    check           => 'ls -l /usr/sbin/lsmod /usr/sbin/rmmod /usr/sbin/insmod /usr/sbin/modinfo /usr/sbin/modprobe /usr/sbin/depmod | grep -v " -> ../bin/kmod"',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => '',
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "the symlinks that kmod accepts should indeed pointing at it on ${title}, but it is NOT",
  }
  include linux_secured::internal::refresh_audit_daemon
}
