#
# linux_secured::validators::last_logged_in_user_display_is_disabled
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# GDM is the GNOME Display Manager which handles graphical login for
# GNOME based systems.
# 
# 
# ## Rationale
# 
# Displaying the last logged in user eliminates half of the Userid/Password equation that an unauthorized person would need to log on.
# 
# Warning messages inform users who are attempting to login to the system of their legal status regarding the system and must include the name of the organization that owns the system and any monitoring policies that are in place.
# Notes:
# 
# - If a graphical login is not required, it should be removed to reduce the attack surface of the system.
# - If a different GUI login service is in use and required on the system, consult your documentation to disable displaying the last logged on user
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::last_logged_in_user_display_is_disabled: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `last_logged_in_user_display_is_disabled` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 1.8.3
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 1.8.3
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::last_logged_in_user_display_is_disabled (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "last_logged_in_user_display_is_disabled validation on ${title}":
    ensure => 'present',
  }

  -> validation { "last logged in user display is configured on ${title}":
    check           => 'cat /etc/dconf/profile/gdm',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => [
      /user-db:user/,
      /system-db:gdm/,
      Regexp('file-db:/usr/share/gdm/greeter-dconf-defaults'),
    ],
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "last logged in user display should be configured on ${title}, but it is NOT",
  }

  -> validation { "last logged in user display is disabled on ${title}":
    check           => 'cat /etc/dconf/db/gdm.d/00-login-screen',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => [
      Regexp('[org/gnome/login-screen]'),
      Regexp('disable-user-list=true\''),
    ],
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "last logged in user display should be configured on ${title}, but it is NOT",
  }
}
