#
# linux_secured::validators::lockout_for_failed_password_attempts_is_configured
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# Lock out users after n unsuccessful consecutive login attempts.-
# deny=<n> - Number of attempts before the account is locked- unlock_time=<n>
# - Time in seconds before the account is unlockedNote: The maximum configurable
# value for unlock_time is 604800 
# 
# 
# ## Rationale
# 
# Locking out user IDs after n unsuccessful consecutive login attempts mitigates brute force password attacks against your systems.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::lockout_for_failed_password_attempts_is_configured: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `lockout_for_failed_password_attempts_is_configured` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.5.2
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.5.2
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::lockout_for_failed_password_attempts_is_configured (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "lockout_for_failed_password_attempts_is_configured validation on ${title}":
    ensure => 'present',
  }

  if Integer($facts['os']['release']['minor']) >= 2 {
    validation { "lockout for failed password attempts is configured on ${title}":
      check          => "grep -E '^\\s*deny\\s*=\s*[1-5]\\b' /etc/security/faillock.conf",
      path           => ['/usr/sbin/', '/usr/bin'],
      parse_value    => /=\s(.*)/,
      expected_value => [
        '> 0',
        '<= 5',
      ],
      skip           => $skip,
      report_as      => $report_as,
      control        => easy_type::current_control(),
      fail_message   => "lockout for failed password attempts should be configured on ${title}, but it is NOT",
      require        => Linux_secured_setup["lockout_for_failed_password_attempts_is_configured validation on ${title}"],
    }

    validation { "unlock_time after failed password attempts is configured on ${title}":
      check          => "grep -E '^\\s*unlock_time\\s*=\\s*(0|9[0-9][0-9]|[1-9][0-9][0-9][0-9]+)\\b' /etc/security/faillock.conf",
      path           => ['/usr/sbin/', '/usr/bin'],
      parse_value    => /=\s(.*)/,
      expected_value => [
        '>= 900 || $value.to_i == 0',
      ],
      skip           => $skip,
      report_as      => $report_as,
      control        => easy_type::current_control(),
      fail_message   => "lockout for failed password attempts should be configured on ${title}, but it is NOT",
      require        => Linux_secured_setup["lockout_for_failed_password_attempts_is_configured validation on ${title}"],
    }
  } else {
    alert('Specified CIS validator is not yet defined for older OS versions.')
  }
}
