#
# linux_secured::validators::mail_transfer_agent_is_configured_for_local_only_mode
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# Mail Transfer Agents (MTA), such as sendmail and Postfix, are used
# to listen for incoming mail and transfer the messages to the appropriate user
# or mail server. If the system is not intended to be a mail server, it is recommended
# that the MTA be configured to only process local mail.
# 
# 
# ## Rationale
# 
# The software for all Mail Transfer Agents is complex and most have a long history of security issues. While it is important to ensure that the system can process local mail messages, it is not necessary to have the MTA's daemon listening on a port unless the server is intended to be a mail server that receives and processes mail from other systems.
# 
# 
# **Notes**:
# - This recommendation is designed around the postfix mail server.
# - Depending on your environment you may have an alternative MTA installed such as
# sendmail. If this is the case consult the documentation for your installed MTA to configure the recommended state.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::mail_transfer_agent_is_configured_for_local_only_mode: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `mail_transfer_agent_is_configured_for_local_only_mode` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 2.2.17
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 2.2.17
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::mail_transfer_agent_is_configured_for_local_only_mode (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "mail_transfer_agent_is_configured_for_local_only_mode validation on ${title}":
    ensure => 'present',
  }

  -> validation { "mail transfer agent is configured for local-only mode on ${title}":
    check           => "ss -lntu | grep -E ':25\\s' | grep -E -v '\\s(127.0.0.1|\\[?::1\\]?):25\\s'",
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => '',
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "mail transfer agent should be configured for local-only mode on ${title}, but it is NOT",
  }
}
