#
# linux_secured::validators::minimum_days_between_password_changes_is_7_or_more
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `PASS_MIN_DAYS` parameter in /etc/login.defs allows an administrator
# to prevent users from changing their password until a minimum number of days have
# 
# 
# ## Rationale
# 
# By restricting the frequency of password changes, an administrator can prevent users from repeatedly changing their password in an attempt to circumvent password reuse controls.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::minimum_days_between_password_changes_is_7_or_more: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `minimum_days_between_password_changes_is_7_or_more` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.6.1.2
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.6.1.2
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::minimum_days_between_password_changes_is_7_or_more (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "minimum_days_between_password_changes_is_7_or_more validation on ${title}":
    ensure => 'present',
  }

  -> validation { "minimum days between password changes policy is 7 or more on ${title}":
    check          => "grep ^\\s*PASS_MIN_DAYS /etc/login.defs",
    path           => ['/usr/sbin/', '/usr/bin'],
    parse_value    => Regexp('\w+[\t|\s](.*)'),
    expected_value => '>= 7',
    report_as      => $report_as,
    skip           => $skip,
    control        => easy_type::current_control(),
    fail_message   => "minimum days between password changes policy is 7 or more on ${title}, but it is NOT",
  }

  -> validation { "minimum days between password changes for all users is 7 or moreon ${title}":
    check           => 'puppet facts users_with_short_expiration',
    path            => ['/usr/sbin/', '/usr/bin', '/opt/puppetlabs/bin'],
    expected_output => Regexp('[\n\n  ]\n'),
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "minimum days between password changes for all users should be  7 or more on ${title}, but it is NOT",
  }
}
