#
# linux_secured::validators::nfs_utils_is_not_installed_or_the_nfs_server_service_is_masked
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The Network File System (NFS) is one of the first and most widely
# distributed file systems in the UNIX environment. It provides the ability for
# systems to mount file systems of other servers through the network.
# 
# 
# ## Rationale
# 
# If the system does not require network shares, it is recommended that the `nfs-utils` package be removed to reduce the attack surface of the system.
# 
# 
# 
# 
# ## Impact
# 
# Many of the `libvirt` packages used by Enterprise Linux virtualization are dependent on the `nfs-utils` package. If the nfs-package is required as a dependency, the nfs-server should be disabled and masked to reduce the attack surface of the system.
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::nfs_utils_is_not_installed_or_the_nfs_server_service_is_masked: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `nfs_utils_is_not_installed_or_the_nfs_server_service_is_masked` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 2.2.18
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 2.2.18
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::nfs_utils_is_not_installed_or_the_nfs_server_service_is_masked (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "nfs_utils_is_not_installed_or_the_nfs_server_service_is_masked validation on ${title}":
    ensure => 'present',
  }

  #
  # For now we choose masking the service, because it can be used more widely
  #
  # -> validation { "nfs-utils is not installed on ${title}":
  #   check           => 'rpm -q nfs-utils',
  #   path            => ['/usr/sbin/', '/usr/bin'],
  #   expected_output => /package nfs-utils is not installed/,
  #   report_as       => $report_as,
  # skip                => $skip,
  #   fail_message    => "nfs-utils should NOT be installed on ${title}, but it IS",
  # }

  -> validation { "nfs-server is masked on ${title}":
    check           => 'systemctl is-enabled nfs-server',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => /masked|No such file or directory/,
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "nfs-server should be masked on ${title}, but it is NOT",
  }
}
