#
# linux_secured::validators::nftables_base_chains_exist
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# Chains are containers for rules. They exist in two kinds, base chains
# and regular chains. A base chain is an entry point for packets from the networking
# stack, a regular chain may be used as jump target and is used for better rule
# organization.
# 
# 
# ## Rationale
# 
# If a base chain doesn't exist with a hook for input, forward, and delete, packets that would flow through those chains will not be touched by nftables.
# 
# 
# 
# ## Impact
# 
# If configuring nftables over ssh, creating a base chain with a policy of drop will cause loss of connectivity.
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::nftables_base_chains_exist: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `nftables_base_chains_exist` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 3.4.2.6
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 3.4.2.6
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::nftables_base_chains_exist (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "nftables_base_chains_exist validation on ${title}":
    ensure => 'present',
  }

  ['input', 'forward', 'output'].each |$chain| {
    validation { "nftables base chain ${chain} exist on ${title}":
      check           => "nft list ruleset | grep 'hook ${chain}'",
      path            => ['/usr/sbin/', '/usr/bin'],
      expected_output => Regexp("hook ${chain}"),
      report_as       => $report_as,
      skip            => $skip,
      control         => easy_type::current_control(),
      fail_message    => "nftables base chain ${chain} should exist on ${title}, but it is NOT",
      require         => Linux_secured_setup["nftables_base_chains_exist validation on ${title}"],
    }
  }
}
