#
# linux_secured::validators::password_creation_requirements_are_configured
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `pam_pwquality.so` module checks the strength of passwords. It performs checks such as making sure a password is not a dictionary word, it is a certain length, contains a mix of characters (e.g. alphabet, numeric, other) and more. The following are definitions of the p`am_pwquality.so` options.
# - `try_first_pass` - retrieve the password from a previous stacked PAM module. If not available, then prompt the user for a password.
# - `retry=3` - Allow 3 tries before sending back a failure.
# - `minlen=14` - password must be 14 characters or more
# ** Either of the following can be used to enforce complex passwords:**
# - `minclass=4` - provide at least four classes of characters for the new password
# 
# OR
# 
# - `dcredit=-1` - provide at least one digit
# - `ucredit=-1` - provide at least one uppercase character
# - `ocredit=-1` - provide at least one special character
# - `lcredit=-1` - provide at least one lowercase character
# 
# The settings shown above are one possible policy. Alter these values to conform to your own organization's password policies
# 
# 
# ## Rationale
# 
# Strong passwords protect systems from being hacked through brute force methods.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::password_creation_requirements_are_configured: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `password_creation_requirements_are_configured` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.5.1
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.5.1
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::password_creation_requirements_are_configured (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "password_creation_requirements_are_configured validation on ${title}":
    ensure => 'present',
  }

  -> validation { "password creation requirements are configured on ${title}":
    check           => 'grep pam_pwquality.so /etc/pam.d/system-auth /etc/pam.d/password-auth',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => [
      /password\s+requisite\s+pam_pwquality.so\s+try_first_pass\s+local_users_only\s+enforce_for_root\s+retry=3/,
      /password\s+requisite\s+pam_pwquality.so\s+try_first_pass\s+local_users_only\s+enforce_for_root\s+retry=3/,
    ],
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "password creation requirements should be configured on ${title}, but they are NOT",
  }

  -> validation { "password length is configured on ${title}":
    check          => 'grep ^minlen /etc/security/pwquality.conf',
    path           => ['/usr/sbin/', '/usr/bin'],
    expected_value => '>= 14',
    parse_value    => /.*=\s (.*)/,
    report_as      => $report_as,
    skip           => $skip,
    control        => easy_type::current_control(),
    fail_message   => "password length should be configured on ${title}, but it is NOT",
  }
}
