#
# linux_secured::validators::password_expiration_warning_days_is_7_or_more
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `PASS_WARN_AGE` parameter in /etc/login.defs allows an administrator
# to notify users that their password will expire in a defined number of days. It
# is recommended that the `PASS_WARN_AGE` parameter be set to 7 or more days.
# 
# 
# ## Rationale
# 
# Providing an advance warning that a password will be expiring gives users time to think of a secure password. Users caught unaware may choose a simple password or write it down where it may be discovered.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::password_expiration_warning_days_is_7_or_more: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `password_expiration_warning_days_is_7_or_more` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.6.1.3
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.6.1.3
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::password_expiration_warning_days_is_7_or_more (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "password_expiration_warning_days_is_7_or_more validation on ${title}":
    ensure => 'present',
  }

  -> validation { "password expiration policy warning days is 7 or more on ${title}":
    check          => "grep -e '^PASS_WARN_AGE' /etc/login.defs",
    path           => ['/usr/sbin/', '/usr/bin'],
    parse_value    => Regexp('\w+[\t|\s](.*)'),
    expected_value => '>= 7',
    report_as      => $report_as,
    control        => easy_type::current_control(),
    fail_message   => "password expiration policy warning days should be 7 or more on ${title}, but it is NOT",
  }

  -> validation { "password expiration warning days for all users is 7 or more on ${title}":
    check           => 'puppet facts users_with_short_warning_periode',
    path            => ['/usr/sbin/', '/usr/bin', '/opt/puppetlabs/bin'],
    expected_output => Regexp('[\n\n  ]\n'),
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "password expiration warning days for all users should be 7 or more on ${title}, but it is NOT",
  }
}
