#
# linux_secured::validators::password_hashing_algorithm_is_sha_512
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# A cryptographic hash function converts an arbitrary-length input into
# a fixed length output. Password hashing performs a one-way transformation of a
# password, turning the password into another string, called the hashed password.
# 
# 
# ## Rationale
# 
# The SHA-512 algorithm provides stronger hashing than other hashing algorithms used for password hashing with Linux, providing additional protection to the system by increasing the level of effort for an attacker to successfully determine passwords.
# 
# 
# **Note**: These changes only apply to accounts configured on the local system.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::password_hashing_algorithm_is_sha_512: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `password_hashing_algorithm_is_sha_512` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.5.4
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.5.4
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::password_hashing_algorithm_is_sha_512 (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "password_hashing_algorithm_is_sha_512 validation on ${title}":
    ensure => 'present',
  }

  -> validation { "password hashing algorithm is SHA-512 in libuser.conf on ${title}":
    check           => "grep -Ei '^\\s*crypt_style\\s*=\\s*sha512\\b' /etc/libuser.conf",
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => /crypt_style = sha512/,
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "password hashing algorithm should be SHA-512 in libuser.conf on ${title}, but it is NOT",
  }

  -> validation { "password hashing algorithm is SHA-512 in login.defs on ${title}":
    check           => "grep -Ei '^\\s*ENCRYPT_METHOD\\s+SHA512\\b' /etc/login.defs",
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => /ENCRYPT_METHOD SHA512/,
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "password hashing algorithm should be SHA-512 in login.defs on ${title}, but it is NOT",
  }

  -> validation { "password hashing algorithm is SHA-512 in password-auth on ${title}":
    check           => "grep -P -- '^\\h*password\\h+(requisite|required|sufficient)\\h+pam_unix\\.so(\\h+[^#\\n\\r]+)? \\h+sha512\\b.*$' /etc/pam.d/password-auth and /etc/pam.d/system-auth",
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => [
      /\/etc\/pam.d\/password-auth:password\s+sufficient\s+pam_unix.so\s+sha512\s+shadow\s+try_first_pass\s+use_authtok\s+remember=5/,
      /\/etc\/pam.d\/system-auth:password\s+sufficient\s+pam_unix.so\s+sha512\s+shadow\s+try_first_pass\s+use_authtok\s+remember=5/,
    ],
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "password hashing algorithm should be SHA-512 in password-auth on ${title}, but it is NOT",
  }
}
