#
# linux_secured::validators::permissions_on_etc_cron_weekly_are_configured
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `/etc/cron.weekly` directory contains system `cron` jobs that
# need to run on a weekly basis. The files in this directory cannot be manipulated
# by the `crontab` command, but are instead edited by system administrators using
# a text editor. The commands below restrict read/write and search access to user
# and group root, preventing regular users from accessing this directory.
# 
# 
# ## Rationale
# 
# Granting write access to this directory for non-privileged users could provide them the means for gaining unauthorized elevated privileges. Granting read access to this directory could give an unprivileged user insight in how to gain elevated privileges or circumvent auditing controls.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::permissions_on_etc_cron_weekly_are_configured: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `permissions_on_etc_cron_weekly_are_configured` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.1.5
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.1.5
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::permissions_on_etc_cron_weekly_are_configured (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "permissions_on_etc_cron_weekly_are_configured validation on ${title}":
    ensure => 'present',
  }

  -> validation { "permissions on /etc/cron.weekly are configured on ${title}":
    check           => "stat /etc/cron.weekly | grep 'Access: ('",
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => "Access: (0700/drwx------)  Uid: (    0/    root)   Gid: (    0/    root)\n",
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "permissions on /etc/cron.weekly should be configured correctly on ${title}, but they are NOT",
  }
}
