#
# linux_secured::validators::permissions_on_ssh_private_host_key_files_are_configured
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# an SSH private key is one of two files used in SSH public key authentication.
# In this authentication method, the possession of the private key is proof of identity.
# Only a private key that corresponds to a public key will be able to authenticate
# successfully. The private keys need to be stored and handled carefully, and no
# copies of the private key should be distributed.
# 
# 
# ## Rationale
# 
# If an unauthorized user obtains the private SSH host key file, the host could be impersonated
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::permissions_on_ssh_private_host_key_files_are_configured: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `permissions_on_ssh_private_host_key_files_are_configured` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.2.2
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.2.2
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::permissions_on_ssh_private_host_key_files_are_configured (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "permissions_on_ssh_private_host_key_files_are_configured validation on ${title}":
    ensure => 'present',
  }

  -> validation { "permissions on SSH private host key files are configured on ${title}":
    check           => 'puppet facts incorrect_configured_private_host_keys',
    path            => ['/usr/sbin/', '/usr/bin', '/opt/puppetlabs/puppet/bin'],
    expected_output => Regexp('[\n\n  ]\n'),
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "permissions on SSH private host key files should be configured on ${title}, but they are NOT",
  }
}
