#
# linux_secured::validators::rsync_is_not_installed_or_the_rsyncd_service_is_masked
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The rsyncd service can be used to synchronize files between systems
# over network links. 
# 
# 
# ## Rationale
# 
# Unless required, the rsync package should be removed to reduce the attack surface area of the system.
# The rsyncd service presents a security risk as it uses unencrypted protocols for communication.
# 
# 
#  **Note**: If a required dependency exists for the rsync package, but the rsyncd service is not required, the service should be masked.
# 
# 
# 
# 
# ## Impact
# 
# There are packages that are dependent on the rsync package. If the rsync package is removed, these packages will be removed as well.
# 
# Before removing the rsync package, review any dependent packages to determine if they are required on the system. If a dependent package is required, mask the rsyncd service and leave the rsync package installed.
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::rsync_is_not_installed_or_the_rsyncd_service_is_masked: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `rsync_is_not_installed_or_the_rsyncd_service_is_masked` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 2.2.20
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 2.2.20
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::rsync_is_not_installed_or_the_rsyncd_service_is_masked (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "rsync_is_not_installed_or_the_rsyncd_service_is_masked validation on ${title}":
    ensure => 'present',
  }
  #
  # For now we choose masking the service, because it can be used more widely
  #
  # -> validation { "rsync is not installed on ${title}":
  #   check           => 'rpm -q rsync',
  #   path            => ['/usr/sbin/', '/usr/bin'],
  #   expected_output => /package rsync is not installed/,
  #   report_as       => $report_as,
  # skip                => $skip,
  #   fail_message    => "rsync should NOT be installed on ${title}, but it IS",
  # }

  -> validation { "rsync is masked on ${title}":
    check           => 'systemctl is-enabled rsync',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => /masked|No such file or directory/,
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "rsync should be masked on ${title}, but it is NOT",
  }
}
