#
# linux_secured::validators::rsyslog_is_not_configured_to_recieve_logs_from_a_remote_client
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# RSyslog supports the ability to receive messages from remote hosts,
# thus acting as a log server. Clients should not receive data from other hosts.
# 
# 
# ## Rationale
# 
# If a client is configured to also receive data, thus turning it into a server, the client system is acting outside it's operational boundary.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::rsyslog_is_not_configured_to_recieve_logs_from_a_remote_client: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `rsyslog_is_not_configured_to_recieve_logs_from_a_remote_client` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 4.2.1.7
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::rsyslog_is_not_configured_to_recieve_logs_from_a_remote_client (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "rsyslog_is_not_configured_to_recieve_logs_from_a_remote_client validation on ${title}":
    ensure => 'present',
  }

  -> validation { "rsyslog is not configured to recieve logs from a remote client on ${title}":
    check              => 'cat /etc/rsyslog.conf /etc/rsyslog.d/*.conf',
    path               => ['/usr/sbin/', '/usr/bin'],
    not_allowed_output => [
      Regexp('^\h*module\(load="imtcp"\)'),
      Regexp('^\h*input\(type="imtcp" port="514"\)'),
    ],
    report_as          => $report_as,
    fail_message       => "rsyslog SHOULD NOT be configured to recieve logs from a remote client on ${title}, but it IS",
  }
}
