#
# linux_secured::validators::ssh_idle_timeout_interval_is_configured
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The two options `ClientAliveInterval` and `ClientAliveCountMax` control
# the timeout of ssh sessions.- `ClientAliveInterval` sets a timeout interval
# in seconds after which if no data has been received from the client, sshd will
# send a message through the encrypted channel to request a response from the client.
# The default is 0, indicating that these messages will not be sent to the client.-
# `ClientAliveCountMax` sets the number of client alive messages which may be sent
# without sshd receiving any messages back from the client. If this threshold is
# reached while client alive messages are being sent, sshd will disconnect the client,
# terminating the session. The default value is 3.    - The client alive messages
# are sent through the encrypted channel     - Setting `ClientAliveCountMax` to
# 0 disables connection terminationExample: The default value is 3. If `ClientAliveInterval`
# is set to 15, and `ClientAliveCountMax` is left at the default, unresponsive SSH
# clients will be disconnected after approximately 45 seconds
# 
# 
# ## Rationale
# 
# Having no timeout value associated with a connection could allow an unauthorized user access to another user's ssh session (e.g. user walks away from their computer and doesn't lock the screen). Setting a timeout value reduces this risk.
# - The recommended `ClientAliveInterval` setting is no greater than 900 seconds (15 minutes)
# - The recommended `ClientAliveCountMax` setting is 0
# - At the 15 minute interval, if the ssh session is inactive, the session will be terminated.
# 
# 
# 
# 
# ## Impact
# 
# In some cases this setting may cause termination of long-running scripts over SSH or remote automation tools which rely on SSH. In developing the local site policy, the requirements of such scripts should be considered and appropriate ServerAliveInterval and `ClientAliveInterval` settings should be calculated to insure operational continuity.
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::ssh_idle_timeout_interval_is_configured: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `ssh_idle_timeout_interval_is_configured` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.2.20
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.2.20
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::ssh_idle_timeout_interval_is_configured (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "ssh_idle_timeout_interval_is_configured validation on ${title}":
    ensure => 'present',
  }

  -> validation { "SSH Idle Timeout Interval is configured on ${title}":
    check           => 'sshd -T -C user=root -C host="$(hostname)" -C addr="$(grep $(hostname) /etc/hosts | awk \'{print $1}\')"',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => [
      /clientaliveinterval 900/,
      /clientalivecountmax 3/,
    ],
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "SSH Idle Timeout Interval should be configured on ${title}, but it is NOT",
  }
}
