#
# linux_secured::validators::ssh_pam_is_enabled
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# UsePAM Enables the Pluggable Authentication Module interface. If set
# to “yes” this will enable PAM authentication using ChallengeResponseAuthentication
# and PasswordAuthentication in addition to PAM account and session module processing
# for all authentication types
# 
# 
# ## Rationale
# 
# When usePAM is set to yes, PAM runs through account and session types properly. This is important if you want to restrict
# access to services based off of IP, time or other factors of the account. Additionally, you can make sure users inherit certain
# environment variables on login or disallow access to the server.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::ssh_pam_is_enabled: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `ssh_pam_is_enabled` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.2.6
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.2.6
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::ssh_pam_is_enabled (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "ssh_pam_is_enabled validation on ${title}":
    ensure => 'present',
  }

  -> validation { "SSH PAM is enabled on ${title}":
    check           => 'sshd -T -C user=root -C host="$(hostname)" -C addr="$(grep $(hostname) /etc/hosts | awk \'{print $1}\')"',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => /usepam yes/,
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "SSH PAM should be enabled on ${title}, but it is NOT",
  }
}
