#
# linux_secured::validators::sticky_bit_is_set_on_all_world_writable_directories
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# Setting the sticky bit on world writable directories prevents users from deleting or renaming files in that directory that are not owned by them.
# 
# 
# ## Rationale
# 
# This feature prevents the ability to delete or rename files in world writable directories (such as `/tmp` ) that are owned by another user.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::sticky_bit_is_set_on_all_world_writable_directories: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `sticky_bit_is_set_on_all_world_writable_directories` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 6.1.2
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 6.1.2
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::sticky_bit_is_set_on_all_world_writable_directories (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "sticky_bit_is_set_on_all_world_writable_directories validation on ${title}":
    ensure => 'present',
  }

  # lint:ignore:strict_indent
  -> validation { "sticky bit is set on all world-writable directories on ${title}":
    check           => @(SCRIPT),
    df --local -P | awk '{if (NR!=1) print $6}' | xargs -I '{}' find '{}' -xdev -type d \( -perm -0002 -a ! -perm -1000 \) 2>/dev/null
    | SCRIPT
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => '',
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "sticky bit should be set on all world-writable directories on ${title}, but it is NOT",
  }
  # lint:endignore:strict_indent
}
