#
# linux_secured::validators::sudo_log_file_exists
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# sudo can use a custom log file
# 
# 
# ## Rationale
# 
# A sudo log file simplifies auditing of sudo commands
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::sudo_log_file_exists: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `sudo_log_file_exists` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.3.3
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.3.3
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::sudo_log_file_exists (
  Boolean              $skip      = linux_secured::lookup_setting('skip', false),
  Stdlib::Absolutepath $log_file  = linux_secured::lookup_setting('log_file', '/var/log/sudo.log'),
  String[1]            $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "sudo_log_file_exists validation on ${title}":
    ensure => 'present',
  }

  -> validation { "sudo log file existson ${title}":
    check           => "grep -rPi '^\\h*Defaults\\h+([^#\\n\\r]+,)?' /etc/sudoers*",
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => Regexp("Defaults logfile=\"${log_file}\""),
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "sudo log should file exists on ${title}, but it is NOT",
  }
}
