#
# linux_secured::validators::systemd_journal_remote_is_installed
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# Journald (via `systemd-journal-remote`) supports the ability to send log events it gathers to a remote log host or to receive messages
# from remote hosts, thus enabling centralised log management.
# 
# 
# ## Rationale
# 
# Storing log data on a remote host protects log integrity from local attacks. If an attacker gains root access on the local system,
# they could tamper with or remove log data that is stored on the local system.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::systemd_journal_remote_is_installed: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `systemd_journal_remote_is_installed` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 4.2.2.1.1
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::systemd_journal_remote_is_installed (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "systemd_journal_remote_is_installed validation on ${title}":
    ensure => 'present',
  }

  -> validation { "tystemd-journal-remote is installed on ${title}":
    check           => 'rpm -q systemd-journal-remote',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => /systemd-journal-remote-/,
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "systemd-journal-remote should be installed on ${title}, but it IS",
  }
}
