#
# linux_secured::validators::tcp_syn_cookies_is_enabled
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# When tcp_syncookies is set, the kernel will handle TCP SYN packets
# normally until the half-open connection queue is full, at which time, the SYN
# cookie functionality kicks in. SYN cookies work by not using the SYN queue at
# all. Instead, the kernel simply replies to the SYN with a SYN|ACK, but will include
# a specially crafted TCP sequence number that encodes the source and destination
# IP address and port number and the time the packet was sent. A legitimate connection
# would send the ACK packet of the three way handshake with the specially crafted
# sequence number. This allows the system to verify that it has received a valid
# response to a SYN cookie and allow the connection, even though there is no corresponding
# SYN in the queue.
# 
# 
# ## Rationale
# 
# Attackers use SYN flood attacks to perform a denial of service attacked on a system by sending many SYN packets without completing the three way handshake. This will quickly use up slots in the kernel's half-open connection queue and prevent legitimate connections from succeeding. SYN cookies allow the system to keep accepting valid connections, even if under a denial of service attack.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::tcp_syn_cookies_is_enabled: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `tcp_syn_cookies_is_enabled` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 3.3.8
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 3.3.8
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::tcp_syn_cookies_is_enabled (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "tcp_syn_cookies_is_enabled validation on ${title}":
    ensure => 'present',
  }

  -> validation { "TCP SYN Cookies is enabled on ${title}":
    check           => "bash ${linux_secured::sysctl_value('net.ipv4.tcp_syncookies', '1')}",
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => /PASS/,
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "TCP SYN Cookies should be enabled on ${title}, but it is NOT",
  }
}
