#
# linux_secured::validators::use_of_privileged_commands_are_collected
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# bit set on execution, to determine if unprivileged users are running these commands.
# 
# 
# ## Rationale
# 
# Execution of privileged commands by non-privileged users could be an indication of someone trying to gain unauthorized access to the system.
# 
# 
# 
# 
# ## Impact
# 
# Both the audit and remediation section of this recommendation will traverse all mounted file systems that is not mounted with either noexec or nosuid mount options. If there are large file systems without these mount options, such traversal will be significantly detrimental to the performance of the system.
# Before running either the audit or remediation section, inspect the output of the following command to determine exactly which file systems will be traversed:
# 
# ```
# findmnt -n -l -k -it $(awk '/nodev/ { print $2 }' /proc/filesystems | paste -sd,) | grep -Pv "noexec|nosuid"
# ```
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::use_of_privileged_commands_are_collected: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `use_of_privileged_commands_are_collected` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 4.1.3.6
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 4.1.3.6
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::use_of_privileged_commands_are_collected (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  $validation_array = $facts['privileged_commands'].map |$command| {
    Regexp("-a always,exit -S all -F path=${command} -F perm=x -F auid>=${facts['uid_min']} -F auid!=-1 -F key=privileged")
  }

  linux_secured_setup { "use_of_privileged_commands_are_collected validation on ${title}":
    ensure => 'present',
  }

  -> validation { "use of privileged commands are collected on ${title}":
    check           => 'auditctl -l',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => $validation_array,
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "use of privileged commands should be collected on ${title}, but they are NOT",
    require         => Exec['refresh audit deamon'],
  }
  include linux_secured::internal::refresh_audit_daemon
}
