#
# linux_secured::validators::xorg_x11_server_common_is_not_installed
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The X Window System provides a Graphical User Interface (GUI) where
# users can have multiple windows in which to run programs and various add on. The
# X Windows system is typically used on workstations where users login, but not
# on servers where users typically do not login.
# 
# 
# ## Rationale
# 
# Unless your organization specifically requires graphical login access via X Windows, remove it to reduce the potential attack surface.
# 
# 
# 
# 
# ## Impact
# 
# Many Linux systems run applications which require a Java runtime. Some Linux Java packages have a dependency on specific X Windows xorg-x11-fonts. One workaround to avoid this dependency is to use the "headless" Java packages for your specific Java runtime.
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::xorg_x11_server_common_is_not_installed: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `xorg_x11_server_common_is_not_installed` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 2.2.2
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 2.2.2
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::xorg_x11_server_common_is_not_installed (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "xorg_x11_server_common_is_not_installed validation on ${title}":
    ensure => 'present',
  }

  -> validation { "xorg-x11-server-common is not installed on ${title}":
    check           => 'rpm -q xorg-x11-server-common',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => /package xorg-x11-server-common is not installed/,
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "xorg-x11-server-common should NOT be installed on ${title}, but it IS",
  }
}
