#
# linux_secured::validators::address_space_layout_randomization_aslr_is_enabled
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# Address space layout randomization (ASLR) is an exploit mitigation
# technique which randomly arranges the address space of key data areas of a process.
# 
# 
# ## Rationale
# 
# Randomly placing virtual memory regions will make it difficult to write memory page exploits as the memory placement will be consistently shifting.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::address_space_layout_randomization_aslr_is_enabled: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `address_space_layout_randomization_aslr_is_enabled` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 1.5.3
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 1.5.3
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::address_space_layout_randomization_aslr_is_enabled (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  $script = @(SCRIPT)
    #!/usr/bin/env bash

    {
      krp="" pafile="" fafile=""
      kpname="kernel.randomize_va_space" 
      kpvalue="2"
      searchloc="/run/sysctl.d/*.conf /etc/sysctl.d/*.conf /usr/local/lib/sysctl.d/*.conf /usr/lib/sysctl.d/*.conf /lib/sysctl.d/*.conf /etc/sysctl.conf"
      krp="$(sysctl "$kpname" | awk -F= '{print $2}' | xargs)"
      pafile="$(grep -Psl -- "^\h*$kpname\h*=\h*$kpvalue\b\h*(#.*)?$" $searchloc)"
      fafile="$(grep -s -- "^\s*$kpname" $searchloc | grep -Pv -- "\h*=\h*$kpvalue\b\h*" | awk -F: '{print $1}')"
      if [ "$krp" = "$kpvalue" ] && [ -n "$pafile" ] && [ -z "$fafile" ]; then
          echo -e "\nPASS:\n\"$kpname\" is set to \"$kpvalue\" in the running configuration and in \"$pafile\""
      else
          echo -e "\nFAIL: "
          [ "$krp" != "$kpvalue" ] && echo -e "\"$kpname\" is set to \"$krp\" in the running configuration\n"
          [ -n "$fafile" ] && echo -e "\n\"$kpname\" is set incorrectly in \"$fafile\""
          [ -z "$pafile" ] && echo -e "\n\"$kpname = $kpvalue\" is not set in a kernel parameter configuration file\n"
      fi
    }
    | SCRIPT

  linux_secured_setup { "address_space_layout_randomization_aslr_is_enabled validation on ${title}":
    ensure => 'present',
  }

  -> validation { "address space layout randomization is enabled on ${title}":
    check           => "bash ${script}",
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => /PASS/,
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "address space layout randomization should be enabled on ${title}, but it is NOT",
  }
}
