#
# linux_secured::validators::message_of_the_day_is_configured_properly
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The contents of the `/etc/motd` file are displayed to users after login and function as a message of the day for authenticated users.
# 
# Unix-based systems have typically displayed information about the OS release and patch level upon logging in to the system. This information can be useful to developers who are developing software for a particular OS platform. If mingetty(8) supports the following options, they display operating system information: \m - machine architecture \r - operating system release \s - operating system name \v - operating system version
# 
# 
# ## Rationale
# 
# Warning messages inform users who are attempting to login to the system of their legal status regarding the system and must include the name of the organization that owns the system and any monitoring policies that are in place. Displaying OS and patch level information in login banners also has the side effect of providing detailed system information to attackers attempting to target specific exploits of a system. Authorized users can easily get this information by running the " uname -a " command once they have logged in.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::message_of_the_day_is_configured_properly: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `message_of_the_day_is_configured_properly` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 1.7.1
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 1.7.1
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::message_of_the_day_is_configured_properly (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "message_of_the_day_is_configured_properly validation on ${title}":
    ensure => 'present',
  }

  -> validation { "message of the day is configured properly on ${title}":
    check           => 'cat /etc/motd',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => /\w*/,
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "message of the day is should be defined on ${title}, but it is NOT",
  }

  -> validation { "message of the day contains no info about OS on ${title}":
    # lint:ignore:strict_indent
    check           => @(CMD),
    grep -E -i "(\\\v|\\\r|\\\m|\\\s|$(grep '^ID=' /etc/os-release | cut -d= -f2 | sed -e 's/"//g'))" /etc/motd
    | CMD
    # lint:endignore:strict_indent
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => '',
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "message of the day contains OS info on ${title}, but it should NOT",
  }
}
