#
# linux_secured::validators::permissions_on_bootloader_config_are_configured
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The grub files contain information on boot settings and passwords for unlocking boot options.
# The grub2 configuration is usually grub.cfg. On newer grub2 systems the encrypted bootloader password is contained in user.cfg.
# If the system uses UEFI, /boot/efi is a vfat filesystem. The vfat filesystem itself doesn't have the concept of permissions but can be mounted under Linux with whatever permissions desired.
# 
# 
# ## Rationale
# 
# Setting the permissions to read and write for root only prevents non-root users from seeing the boot parameters or changing them. Non-root users who read the boot parameters may be able to identify weaknesses in security upon boot and be able to exploit them.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::permissions_on_bootloader_config_are_configured: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `permissions_on_bootloader_config_are_configured` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 1.4.2
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 1.4.2
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::permissions_on_bootloader_config_are_configured (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  $script = @(SCRIPT)
    #!/usr/bin/env bash

    {
      output="" output2="" output3="" output4=""
      grubdir=$(dirname "$(find /boot -type f \( -name 'grubenv' -o -name 'grub.conf' -o -name 'grub.cfg' \) -exec grep -Pl '^\h*(kernelopts=|linux|kernel)' {} \;)")
      for grubfile in $grubdir/user.cfg $grubdir/grubenv $grubdir/grub.cfg; do
          if [ -f "$grubfile" ]; then
            if stat -c "%a" "$grubfile" | grep -Pq '^\h*[0-7]00$'; then
                output="$output\npermissions on \"$grubfile\" are \"$(stat -c "%a" "$grubfile")\""
            else
                output3="$output3\npermissions on \"$grubfile\" are \"$(stat -c "%a" "$grubfile")\""
            fi
            if stat -c "%u:%g" "$grubfile" | grep -Pq '^\h*0:0$'; then
                output2="$output2\n\"$grubfile\" is owned by \"$(stat -c "%U" "$grubfile")\" and belongs to group \"$(stat -c "%G" "$grubfile")\""
            else
                output4="$output4\n\"$grubfile\" is owned by \"$(stat -c "%U" "$grubfile")\" and belongs to group \"$(stat -c "%G" "$grubfile")\""
            fi
          fi
      done
      if [[ -n "$output" && -n "$output2" && -z "$output3" && -z "$output4" ]]; then
          echo -e "\nPASSED:"
          [ -n "$output" ] && echo -e "$output"
          [ -n "$output2" ] && echo -e "$output2"
      else
          echo -e "\nFAILED:"
          [ -n "$output3" ] && echo -e "$output3"
          [ -n "$output4" ] && echo -e "$output4"
      fi
    }
    | SCRIPT

  linux_secured_setup { "permissions_on_bootloader_config_are_configured validation on ${title}":
    ensure => 'present',
  }

  -> validation { "bootloader permissions are configured on ${title}":
    check           => "bash ${script}",
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => /PASSED:/,
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "Bootloader permissions on ${title}, are not set correct",
  }
}
