#
# linux_secured::validators::separate_partition_exists_for_var
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `/var` directory is used by daemons and other system services
# to temporarily store dynamic data. Some directories created by these processes
# 
# 
# ## Rationale
# 
# The reasoning for mounting `/var` on a separate partition is as follow. Protection from resource exhaustion The default installation only creates a single `/` partition. Since the `/var` directory may contain world-writable files and directories, there is a risk of resource exhaustion. It will essentially have the whole disk available to fill up and impact the system as a whole. In addition, other operations on the system could fill up the disk unrelated to `/var` and cause unintended behavior across the system as the disk is full. See man auditd.conf for details.
# 
# 
# 
# ## Impact
# 
# Configuring `/var` as its own file system allows an administrator to set additional mount options such as `noexec`/`nosuid`/`nodev`. These options limit an attacker’s ability to create exploits on the system. Other options allow for specific behavior. See man mount for exact details regarding filesystem-independent and filesystem-specific options.
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::separate_partition_exists_for_var: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `separate_partition_exists_for_var` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 1.1.3.1
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 1.1.3.1
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::separate_partition_exists_for_var (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "separate_partition_exists_for_var validation on ${title}":
    ensure => 'present',
  }

  -> validation { 'Validate /var is a separate partition':
    check           => 'findmnt --kernel /var',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => Regexp('/var'),
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => '/var should be a separate partition, but it is NOT.',
  }
}
