#
# linux_secured::validators::ssh_allowtcpforwarding_is_disabled
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# SSH port forwarding is a mechanism in SSH for tunneling application
# ports from the client to the server, or servers to clients. It can be used for
# adding encryption to legacy applications, going through firewalls, and some system
# administrators and IT professionals use it for opening backdoors into the internal
# network from their home machines
# 
# 
# ## Rationale
# 
# Leaving port forwarding enabled can expose the organization to security risks and back- doors.
# SSH connections are protected with strong encryption. This makes their contents invisible to most deployed network monitoring and traffic filtering solutions. This invisibility carries considerable risk potential if it is used for malicious purposes such as data exfiltration. Cybercriminals or malware could exploit SSH to hide their unauthorized communications, or to exfiltrate stolen data from the target network
# 
# 
# 
# 
# ## Impact
# 
# SSH tunnels are widely used in many corporate environments that employ mainframe systems as their application backends. In those environments the applications themselves may have very limited native support for security. By utilizing tunneling, compliance with SOX, HIPAA, PCI-DSS, and other standards can be achieved without having to modify the applications.
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::ssh_allowtcpforwarding_is_disabled: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `ssh_allowtcpforwarding_is_disabled` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 5.2.13
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 5.2.13
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::ssh_allowtcpforwarding_is_disabled (
  Boolean   $skip = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "ssh_allowtcpforwarding_is_disabled validation on ${title}":
    ensure => 'present',
  }

  -> validation { "SSH AllowTcpForwarding is disabled on ${title}":
    check           => 'sshd -T -C user=root -C host="$(hostname)" -C addr="$(grep $(hostname) /etc/hosts | awk \'{print $1}\')"',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => /allowtcpforwarding no/,
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => "SSH AllowTcpForwarding should be disabled ${title}, but it is NOT",
  }
}
