#
# linux_secured::validators::tmp_is_a_separate_partition
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The `/tmp` directory is a world-writable directory used for temporary
# storage by all users and some applications.
# 
# 
# ## Rationale
# 
# Making `/tmp` its own file system allows an administrator to set additional mount options such as the noexec option on the mount, making `/tmp` useless for an attacker to install executable code. It would also prevent an attacker from establishing a hard link to a system setuid program and wait for it to be updated. Once the program was updated, the hard link would be broken and the attacker would have his own copy of the program. If the program happened to have a security vulnerability, the attacker could continue to exploit the known flaw.
# This can be accomplished by either mounting tmpfs to `/tmp`, or creating a separate partition for `/tmp`.
# 
# 
# 
# 
# ## Impact
# 
# Since the `/tmp` directory is intended to be world-writable, there is a risk of resource exhaustion if it is not bound to a separate partition.
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `linux_secured::validators::tmp_is_a_separate_partition: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `tmp_is_a_separate_partition` to the array value `linux_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your systems are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/linux_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Linux 8 CIS V2.0.0](/docs/linux_secured/cis/oraclelinux8_V2.0.0.html) - paragraph 1.1.2.1
# - [RedHat Enterprise Linux 8 CIS V2.0.0](/docs/linux_secured/cis/redhat_el8_V2.0.0.html) - paragraph 1.1.2.1
#
# @param title
#    The system identifier to apply the control to.
#    All controls need an system identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    linux_secured::controls::control_name { 'host':}
#    ```
#    Althoug for `linux_secured` you can put anything in there, it is recommended that yuou use the string `host`.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define linux_secured::validators::tmp_is_a_separate_partition (
  Boolean   $skip      = linux_secured::lookup_setting('skip', false),
  String[1] $report_as = linux_secured::lookup_setting('report_as', 'warning'),
) {
  linux_secured_setup { "tmp_is_a_separate_partition validation on ${title}":
    ensure => 'present',
  }

  -> validation { 'Validate /tmp is a separate partition':
    check           => 'findmnt --kernel /tmp',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => /tmp   tmpfs  tmpfs/,
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => '/tmp should be a separate partition, but it is NOT.',
  }

  -> validation { 'tmp.mount service is enabled':
    check           => 'systemctl is-enabled tmp.mount',
    path            => ['/usr/sbin/', '/usr/bin'],
    expected_output => 'enabled',
    report_as       => $report_as,
    skip            => $skip,
    control         => easy_type::current_control(),
    fail_message    => 'tmp.mount service should be enabled, but it is NOT.',
  }
}
